==> TencentNavKitDocument_7.2.1.zip: TencentNavKitDocument/search/all_15.js <==
var searchData=
[
  ['unavailable_5fattribute_0',['UNAVAILABLE_ATTRIBUTE',['../interface_t_n_k_base_nav_view.html#ac43abee626665d295ffdb6f1cbc8bd7c',1,'TNKBaseNavView']]],
  ['unknowncolor_1',['unknownColor',['../interface_t_n_k_route_color_palette.html#ad1ba846873f90eceeecf4676da5eb4d2',1,'TNKRouteColorPalette']]],
  ['unmuteplayer_2',['unmutePlayer',['../protocol_t_n_k_audio_player_protocol-p.html#a1256832471687cbc7e9f8425499031e5',1,'TNKAudioPlayerProtocol-p']]],
  ['unregisterallnavdelegates_3',['unregisterAllNavDelegates',['../interface_t_n_k_drive_nav_manager.html#a0d86f013460e6a6e9a0b75858820a249',1,'TNKDriveNavManager::unregisterAllNavDelegates()'],['../interface_t_n_k_ride_nav_manager.html#adf092a4aac5449a38647e8ea171cf964',1,'TNKRideNavManager::unregisterAllNavDelegates()'],['../interface_t_n_k_walk_nav_manager.html#afaca07f80465a8d22d4b6c86a35b6314',1,'TNKWalkNavManager::unregisterAllNavDelegates()']]],
  ['unregisternavdelegate_3a_4',['unregisterNavDelegate:',['../interface_t_n_k_drive_nav_manager.html#a161d173a803b91cd006e8c2741e98049',1,'TNKDriveNavManager::unregisterNavDelegate:()'],['../interface_t_n_k_ride_nav_manager.html#aa4f7fa2ac60270da93624bc14ecd77e6',1,'TNKRideNavManager::unregisterNavDelegate:()'],['../interface_t_n_k_walk_nav_manager.html#a4c85ca67b957c4e31148bd033689285e',1,'TNKWalkNavManager::unregisterNavDelegate:()']]],
  ['updatedestinationmarkerpresentation_3a_5',['updateDestinationMarkerPresentation:',['../interface_t_n_k_base_nav_view.html#a63974033cb83f23fb5118ec24cc49e51',1,'TNKBaseNavView']]],
  ['updateenlargedmapconfig_3a_6',['updateEnlargedMapConfig:',['../interface_t_n_k_drive_nav_view.html#aa2a7326f58bf8851e53175e4f4f2c4a1',1,'TNKDriveNavView::updateEnlargedMapConfig:()'],['../interface_t_n_k_travel_nav_view.html#a638434160e3858677eb68d5bac4ceb39',1,'TNKTravelNavView::updateEnlargedMapConfig:()']]],
  ['updateoriginmarkerpresentation_3a_7',['updateOriginMarkerPresentation:',['../interface_t_n_k_base_nav_view.html#af56ca56d0b2aad2f13fafe6be84cf735',1,'TNKBaseNavView']]],
  ['updateredlineconfig_3a_8',['updateRedLineConfig:',['../interface_t_n_k_base_nav_view.html#a255a95795ce370325d14191117644c48',1,'TNKBaseNavView']]],
  ['updaterouteconfig_3a_9',['updateRouteConfig:',['../interface_t_n_k_base_nav_view.html#af2fef5a54f4b50ec32341564cdd3adf1',1,'TNKBaseNavView']]],
  ['updateuserlocationpresentation_3a_10',['updateUserLocationPresentation:',['../interface_t_n_k_base_nav_view.html#a4664f514257ab13681563011496c8f3f',1,'TNKBaseNavView']]],
  ['updatewaypointmarkerpresentation_3a_11',['updateWaypointMarkerPresentation:',['../interface_t_n_k_drive_nav_view.html#a459cf2f38022b082f3f67c9e329aa6dc',1,'TNKDriveNavView::updateWaypointMarkerPresentation:()'],['../interface_t_n_k_travel_nav_view.html#a750b408c1590cd5b1c1efb5eff22a860',1,'TNKTravelNavView::updateWaypointMarkerPresentation:()']]],
  ['userid_12',['userID',['../interface_t_n_k_drive_route_search_option.html#a16827ce0e2bff8447be1a14f92d3d626',1,'TNKDriveRouteSearchOption']]]
];

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/search/all_15.js <==
var searchData=
[
  ['unavailable_5fattribute_0',['UNAVAILABLE_ATTRIBUTE',['../interface_t_n_k_base_nav_view.html#ac43abee626665d295ffdb6f1cbc8bd7c',1,'TNKBaseNavView']]],
  ['unknowncolor_1',['unknownColor',['../interface_t_n_k_route_color_palette.html#ad1ba846873f90eceeecf4676da5eb4d2',1,'TNKRouteColorPalette']]],
  ['unmuteplayer_2',['unmutePlayer',['../protocol_t_n_k_audio_player_protocol-p.html#a1256832471687cbc7e9f8425499031e5',1,'TNKAudioPlayerProtocol-p']]],
  ['unregisterallnavdelegates_3',['unregisterAllNavDelegates',['../interface_t_n_k_drive_nav_manager.html#a0d86f013460e6a6e9a0b75858820a249',1,'TNKDriveNavManager::unregisterAllNavDelegates()'],['../interface_t_n_k_ride_nav_manager.html#adf092a4aac5449a38647e8ea171cf964',1,'TNKRideNavManager::unregisterAllNavDelegates()'],['../interface_t_n_k_walk_nav_manager.html#afaca07f80465a8d22d4b6c86a35b6314',1,'TNKWalkNavManager::unregisterAllNavDelegates()']]],
  ['unregisternavdelegate_3a_4',['unregisterNavDelegate:',['../interface_t_n_k_drive_nav_manager.html#a161d173a803b91cd006e8c2741e98049',1,'TNKDriveNavManager::unregisterNavDelegate:()'],['../interface_t_n_k_ride_nav_manager.html#aa4f7fa2ac60270da93624bc14ecd77e6',1,'TNKRideNavManager::unregisterNavDelegate:()'],['../interface_t_n_k_walk_nav_manager.html#a4c85ca67b957c4e31148bd033689285e',1,'TNKWalkNavManager::unregisterNavDelegate:()']]],
  ['updatedestinationmarkerpresentation_3a_5',['updateDestinationMarkerPresentation:',['../interface_t_n_k_base_nav_view.html#a63974033cb83f23fb5118ec24cc49e51',1,'TNKBaseNavView']]],
  ['updateenlargedmapconfig_3a_6',['updateEnlargedMapConfig:',['../interface_t_n_k_drive_nav_view.html#aa2a7326f58bf8851e53175e4f4f2c4a1',1,'TNKDriveNavView::updateEnlargedMapConfig:()'],['../interface_t_n_k_travel_nav_view.html#a638434160e3858677eb68d5bac4ceb39',1,'TNKTravelNavView::updateEnlargedMapConfig:()']]],
  ['updateoriginmarkerpresentation_3a_7',['updateOriginMarkerPresentation:',['../interface_t_n_k_base_nav_view.html#af56ca56d0b2aad2f13fafe6be84cf735',1,'TNKBaseNavView']]],
  ['updateredlineconfig_3a_8',['updateRedLineConfig:',['../interface_t_n_k_base_nav_view.html#a255a95795ce370325d14191117644c48',1,'TNKBaseNavView']]],
  ['updaterouteconfig_3a_9',['updateRouteConfig:',['../interface_t_n_k_base_nav_view.html#af2fef5a54f4b50ec32341564cdd3adf1',1,'TNKBaseNavView']]],
  ['updateuserlocationpresentation_3a_10',['updateUserLocationPresentation:',['../interface_t_n_k_base_nav_view.html#a4664f514257ab13681563011496c8f3f',1,'TNKBaseNavView']]],
  ['updatewaypointmarkerpresentation_3a_11',['updateWaypointMarkerPresentation:',['../interface_t_n_k_drive_nav_view.html#a459cf2f38022b082f3f67c9e329aa6dc',1,'TNKDriveNavView::updateWaypointMarkerPresentation:()'],['../interface_t_n_k_travel_nav_view.html#a750b408c1590cd5b1c1efb5eff22a860',1,'TNKTravelNavView::updateWaypointMarkerPresentation:()']]],
  ['userid_12',['userID',['../interface_t_n_k_drive_route_search_option.html#a16827ce0e2bff8447be1a14f92d3d626',1,'TNKDriveRouteSearchOption']]],
  ['usesstaticmapwhenappactive_13',['usesStaticMapWhenAppActive',['../interface_t_n_k_snap_shot_config.html#adacc850834c016c45ebe4ed1dde52b29',1,'TNKSnapShotConfig']]]
];
